==> nhc98src-1.18.tar.gz: nhc98-1.18/src/prelude/PreludeText/Show_Float.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v200	((void*)startLabel+36)
#define FN_LAMBDA197	((void*)startLabel+64)
#define CT_v203	((void*)startLabel+96)
#define CF_LAMBDA197	((void*)startLabel+104)
#define CT_v205	((void*)startLabel+152)
#define CT_v207	((void*)startLabel+204)
#define CT_v209	((void*)startLabel+256)
#define CT_v211	((void*)startLabel+320)
#define ST_v202	((void*)startLabel+348)
#define ST_v210	((void*)startLabel+354)
#define ST_v206	((void*)startLabel+381)
#define ST_v208	((void*)startLabel+413)
#define ST_v204	((void*)startLabel+449)
#define ST_v199	((void*)startLabel+486)
#define ST_v201	((void*)startLabel+523)
extern Node TM_Prelude[];
extern Node FN_Prelude_46showString[];
extern Node TMSUB_Prelude[];
extern Node FN_Numeric_46showFloat[];
extern Node CF_Prelude_46RealFloat_46Prelude_46Float[];
extern Node FN_Prelude_46_95_46show[];
extern Node CF_Prelude_46Show_46Prelude_46Float[];
extern Node FN_Prelude_46_95_46showList[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v200)
,};
Node FN_Prelude_46Show_46Prelude_46Float_46showsType[] = {
  useLabel(TM_Prelude)
, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_CVAL_P1,3)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,EVAL,NEEDHEAP_I32)
, bytes2word(APPLY,1,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 70003
, useLabel(ST_v199)
,	/* CT_v200: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Prelude_46Show_46Prelude_46Float_46showsType[] = {
  CAPTAG(useLabel(FN_Prelude_46Show_46Prelude_46Float_46showsType),1)
, useLabel(CF_LAMBDA197)
, VAPTAG(useLabel(FN_Prelude_46showString))
, bytes2word(0,0,0,0)
, useLabel(CT_v203)
,	/* FN_LAMBDA197: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v202)
, 70028
, useLabel(ST_v201)
,	/* CT_v203: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA197: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA197))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v205)
,};
Node FN_Prelude_46Show_46Prelude_46Float_46showsPrec[] = {
  useLabel(TM_Prelude)
, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_ARG_I2,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I3,HEAP_CVAL_I4,ZAP_ARG_I2,EVAL)
, bytes2word(NEEDHEAP_I32,APPLY,1,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 60003
, useLabel(ST_v204)
,	/* CT_v205: (byte 0) */
  HW(2,2)
, 0
,};
Node F0_Prelude_46Show_46Prelude_46Float_46showsPrec[] = {
  CAPTAG(useLabel(FN_Prelude_46Show_46Prelude_46Float_46showsPrec),2)
, VAPTAG(useLabel(FN_Numeric_46showFloat))
, useLabel(CF_Prelude_46RealFloat_46Prelude_46Float)
, bytes2word(1,0,0,1)
, useLabel(CT_v207)
,};
Node FN_Prelude_46Show_46Prelude_46Float_46show[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 50010
, useLabel(ST_v206)
,	/* CT_v207: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Prelude_46Show_46Prelude_46Float_46show[] = {
  CAPTAG(useLabel(FN_Prelude_46Show_46Prelude_46Float_46show),1)
, VAPTAG(useLabel(FN_Prelude_46_95_46show))
, useLabel(CF_Prelude_46Show_46Prelude_46Float)
, bytes2word(1,0,0,1)
, useLabel(CT_v209)
,};
Node FN_Prelude_46Show_46Prelude_46Float_46showList[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 50010
, useLabel(ST_v208)
,	/* CT_v209: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Prelude_46Show_46Prelude_46Float_46showList[] = {
  CAPTAG(useLabel(FN_Prelude_46Show_46Prelude_46Float_46showList),1)
, VAPTAG(useLabel(FN_Prelude_46_95_46showList))
, useLabel(CF_Prelude_46Show_46Prelude_46Float)
, bytes2word(0,0,0,0)
, useLabel(CT_v211)
,};
Node FN_Prelude_46Show_46Prelude_46Float[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_IN3,HEAP_CVAL_I3)
, bytes2word(HEAP_CVAL_I4,HEAP_CVAL_I5,HEAP_CVAL_P1,6)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 0
, CONSTR(0,4,0)
, 50010
, useLabel(ST_v210)
,	/* CT_v211: (byte 0) */
  HW(4,0)
, 0
,};
Node CF_Prelude_46Show_46Prelude_46Float[] = {
  VAPTAG(useLabel(FN_Prelude_46Show_46Prelude_46Float))
, useLabel(F0_Prelude_46Show_46Prelude_46Float_46showsPrec)
, useLabel(F0_Prelude_46Show_46Prelude_46Float_46showsType)
, useLabel(F0_Prelude_46Show_46Prelude_46Float_46showList)
, useLabel(F0_Prelude_46Show_46Prelude_46Float_46show)
,	/* ST_v202: (byte 0) */
  bytes2word(70,108,111,97)
,	/* ST_v210: (byte 2) */
  bytes2word(116,0,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,83,104)
, bytes2word(111,119,46,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,70)
, bytes2word(108,111,97,116)
,	/* ST_v206: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,83,104,111)
, bytes2word(119,46,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,70,108)
, bytes2word(111,97,116,46)
, bytes2word(115,104,111,119)
,	/* ST_v208: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,83,104,111)
, bytes2word(119,46,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,70,108)
, bytes2word(111,97,116,46)
, bytes2word(115,104,111,119)
, bytes2word(76,105,115,116)
,	/* ST_v204: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,83,104,111)
, bytes2word(119,46,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,70,108)
, bytes2word(111,97,116,46)
, bytes2word(115,104,111,119)
, bytes2word(115,80,114,101)
,	/* ST_v199: (byte 2) */
  bytes2word(99,0,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,83,104)
, bytes2word(111,119,46,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,70)
, bytes2word(108,111,97,116)
, bytes2word(46,115,104,111)
, bytes2word(119,115,84,121)
,	/* ST_v201: (byte 3) */
  bytes2word(112,101,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,83)
, bytes2word(104,111,119,46)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(70,108,111,97)
, bytes2word(116,46,115,104)
, bytes2word(111,119,115,84)
, bytes2word(121,112,101,58)
, bytes2word(55,58,50,56)
, bytes2word(45,55,58,51)
, bytes2word(52,0,0,0)
,};

==> nhc98src-1.20.tar.gz: nhc98-1.20/src/prelude/PreludeText/Show_Float.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v209	((void*)startLabel+36)
#define FN_LAMBDA206	((void*)startLabel+64)
#define CT_v212	((void*)startLabel+96)
#define CF_LAMBDA206	((void*)startLabel+104)
#define CT_v214	((void*)startLabel+152)
#define CT_v216	((void*)startLabel+212)
#define CT_v218	((void*)startLabel+264)
#define CT_v220	((void*)startLabel+328)
#define ST_v211	((void*)startLabel+356)
#define ST_v219	((void*)startLabel+362)
#define ST_v215	((void*)startLabel+389)
#define ST_v217	((void*)startLabel+421)
#define ST_v213	((void*)startLabel+457)
#define ST_v208	((void*)startLabel+494)
#define ST_v210	((void*)startLabel+531)
extern Node TM_Prelude[];
extern Node FN_Prelude_46showString[];
extern Node TMSUB_Prelude[];
extern Node FN_Numeric_46showFloat[];
extern Node CF_Prelude_46RealFloat_46Prelude_46Float[];
extern Node FN_Numeric_46showSigned[];
extern Node CF_Prelude_46Real_46Prelude_46Float[];
extern Node FN_Prelude_46_95_46show[];
extern Node CF_Prelude_46Show_46Prelude_46Float[];
extern Node FN_Prelude_46_95_46showList[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v209)
,};
Node FN_Prelude_46Show_46Prelude_46Float_46showsType[] = {
  useLabel(TM_Prelude)
, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_CVAL_P1,3)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,EVAL,NEEDHEAP_I32)
, bytes2word(APPLY,1,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 70003
, useLabel(ST_v208)
,	/* CT_v209: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Prelude_46Show_46Prelude_46Float_46showsType[] = {
  CAPTAG(useLabel(FN_Prelude_46Show_46Prelude_46Float_46showsType),1)
, useLabel(CF_LAMBDA206)
, VAPTAG(useLabel(FN_Prelude_46showString))
, bytes2word(0,0,0,0)
, useLabel(CT_v212)
,	/* FN_LAMBDA206: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v211)
, 70028
, useLabel(ST_v210)
,	/* CT_v212: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA206: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA206))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v214)
,};
Node FN_Prelude_46Show_46Prelude_46Float_46showsPrec[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I5,HEAP_CVAL_P1,6,HEAP_OFF_N1)
, bytes2word(4,HEAP_ARG_ARG_RET_EVAL,1,2)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 60003
, useLabel(ST_v213)
,	/* CT_v214: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_Prelude_46Show_46Prelude_46Float_46showsPrec[] = {
  CAPTAG(useLabel(FN_Prelude_46Show_46Prelude_46Float_46showsPrec),2)
, VAPTAG(useLabel(FN_Numeric_46showFloat))
, useLabel(CF_Prelude_46RealFloat_46Prelude_46Float)
, VAPTAG(useLabel(FN_Numeric_46showSigned))
, useLabel(CF_Prelude_46Real_46Prelude_46Float)
, bytes2word(1,0,0,1)
, useLabel(CT_v216)
,};
Node FN_Prelude_46Show_46Prelude_46Float_46show[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 50010
, useLabel(ST_v215)
,	/* CT_v216: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Prelude_46Show_46Prelude_46Float_46show[] = {
  CAPTAG(useLabel(FN_Prelude_46Show_46Prelude_46Float_46show),1)
, VAPTAG(useLabel(FN_Prelude_46_95_46show))
, useLabel(CF_Prelude_46Show_46Prelude_46Float)
, bytes2word(1,0,0,1)
, useLabel(CT_v218)
,};
Node FN_Prelude_46Show_46Prelude_46Float_46showList[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 50010
, useLabel(ST_v217)
,	/* CT_v218: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Prelude_46Show_46Prelude_46Float_46showList[] = {
  CAPTAG(useLabel(FN_Prelude_46Show_46Prelude_46Float_46showList),1)
, VAPTAG(useLabel(FN_Prelude_46_95_46showList))
, useLabel(CF_Prelude_46Show_46Prelude_46Float)
, bytes2word(0,0,0,0)
, useLabel(CT_v220)
,};
Node FN_Prelude_46Show_46Prelude_46Float[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_IN3,HEAP_CVAL_I3)
, bytes2word(HEAP_CVAL_I4,HEAP_CVAL_I5,HEAP_CVAL_P1,6)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 0
, CONSTR(0,4,0)
, 50010
, useLabel(ST_v219)
,	/* CT_v220: (byte 0) */
  HW(4,0)
, 0
,};
Node CF_Prelude_46Show_46Prelude_46Float[] = {
  VAPTAG(useLabel(FN_Prelude_46Show_46Prelude_46Float))
, useLabel(F0_Prelude_46Show_46Prelude_46Float_46showsPrec)
, useLabel(F0_Prelude_46Show_46Prelude_46Float_46showsType)
, useLabel(F0_Prelude_46Show_46Prelude_46Float_46showList)
, useLabel(F0_Prelude_46Show_46Prelude_46Float_46show)
,	/* ST_v211: (byte 0) */
  bytes2word(70,108,111,97)
,	/* ST_v219: (byte 2) */
  bytes2word(116,0,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,83,104)
, bytes2word(111,119,46,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,70)
, bytes2word(108,111,97,116)
,	/* ST_v215: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,83,104,111)
, bytes2word(119,46,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,70,108)
, bytes2word(111,97,116,46)
, bytes2word(115,104,111,119)
,	/* ST_v217: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,83,104,111)
, bytes2word(119,46,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,70,108)
, bytes2word(111,97,116,46)
, bytes2word(115,104,111,119)
, bytes2word(76,105,115,116)
,	/* ST_v213: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,83,104,111)
, bytes2word(119,46,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,70,108)
, bytes2word(111,97,116,46)
, bytes2word(115,104,111,119)
, bytes2word(115,80,114,101)
,	/* ST_v208: (byte 2) */
  bytes2word(99,0,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,83,104)
, bytes2word(111,119,46,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,70)
, bytes2word(108,111,97,116)
, bytes2word(46,115,104,111)
, bytes2word(119,115,84,121)
,	/* ST_v210: (byte 3) */
  bytes2word(112,101,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,83)
, bytes2word(104,111,119,46)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(70,108,111,97)
, bytes2word(116,46,115,104)
, bytes2word(111,119,115,84)
, bytes2word(121,112,101,58)
, bytes2word(55,58,50,56)
, bytes2word(45,55,58,51)
, bytes2word(52,0,0,0)
,};
